pilas.actores.humo

Package pilas :: Package actores :: Module humo |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.actores.humo

     1  # -*- encoding: utf-8 -*-
     2  # pilas engine - a video game framework.
     3  #
     4  # copyright 2010 - hugo ruscitti
     5  # license: lgplv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # website - http://www.pilas-engine.com.ar
     8
     9  import pilas
    10  from pilas.actores import Animacion
    11
    12 -class Humo(Animacion):
    13      """Muestra una animación de una nube de humo.
    14
    15      .. image:: images/actores/humo.png
    16
    17      La animación se ejecuta una vez y desaparece.
    18
    19      """
    20 -    def __init__(self, x=0, y=0):
    21          """ Constructor del Humo
    22
    23          :param x: Posición horizontal de la explosion.
    24          :type x: int
    25          :param y: Posición vertical de la explosion.
    26          :type y: int
    27          """
    28          grilla = pilas.imagenes.cargar_grilla("humo.png", 4)
    29          Animacion.__init__(self, grilla, x=x, y=y, velocidad=8)
    30